@@ -3,6 +3,38 @@
 set -eux
 
 pacemaker_status=$(systemctl is-active pacemaker)
+check_interval=3
+
+function check_resource {
+
+  service=$1
+  state=$2
+  timeout=$3
+  tstart=$(date +%s)
+  tend=$(( $tstart + $timeout ))
+
+  if [ "$state" = "stopped" ]; then
+      match_for_incomplete='Started'
+  else # started
+      match_for_incomplete='Stopped'
+  fi
+
+  while (( $(date +%s) < $tend )); do
+      node_states=$(pcs status --full | grep "$service" | grep -v Clone)
+      if echo "$node_states" | grep -q "$match_for_incomplete"; then
+          echo "$service not yet $state, sleeping $check_interval seconds."
+          sleep $check_interval
+      else
+        echo "$service has $state"
+        timeout -k 10 $timeout crm_resource --wait
+        return
+      fi
+  done
+
+  echo "$service never $state after $timeout seconds" | tee /dev/fd/2
+  exit 1
+
+}
 
 # Run if pacemaker is running, we're the bootstrap node,
 # and we're updating the deployment (not creating).
@@ -36,9 +68,3 @@ if [ "$pacemaker_status" = "active" -a \
     check_resource httpd started 800
 
 fi
-
-if [ "$pacemaker_status" = "active" ]; then
-    # TODO(marios): remove this once +bug/1561012
-    # need this on all controllers:
-    systemctl reload haproxy
-fi
